<?php

namespace Drupal\template_entities\EntityQuery;

use Drupal\Core\Database\Connection;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\Query\QueryBase;
use Drupal\Core\Entity\Query\Sql\QueryFactory as BaseQueryFactory;
use Drupal\template_entities\TemplateManagerInterface;

/**
 * Template-specific entity query implementation.
 */
class QueryFactory extends BaseQueryFactory {

  /**
   * The template manager.
   *
   * @var \Drupal\template_entities\TemplateManagerInterface
   */
  protected TemplateManagerInterface $templateManager;

  /**
   * Constructs a QueryFactory object.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database connection used by the entity query.
   * @param \Drupal\template_entities\TemplateManagerInterface $template_manager
   *   The template manager.
   */
  public function __construct(Connection $connection, TemplateManagerInterface $template_manager) {
    parent::__construct($connection);
    $this->templateManager = $template_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function get(EntityTypeInterface $entity_type, $conjunction) {
    $class = QueryBase::getClass($this->namespaces, 'Query');
    return new $class($entity_type, $conjunction, $this->connection, $this->namespaces, $this->templateManager);
  }

  /**
   * {@inheritdoc}
   */
  public function getAggregate(EntityTypeInterface $entity_type, $conjunction) {
    $class = QueryBase::getClass($this->namespaces, 'QueryAggregate');
    return new $class($entity_type, $conjunction, $this->connection, $this->namespaces, $this->templateManager);
  }

}
