<?php

namespace Drupal\template_entities\Plugin\TemplatePlugin;

use Drupal;
use Drupal\Component\Plugin\ConfigurableInterface;
use Drupal\Component\Plugin\DependentPluginInterface;
use Drupal\Core\Entity\EntityInterface;

/**
 * Template plugin for nodes.
 *
 * This overrides the derived one but gets derived definition merged in
 * automatically.
 *
 * @TemplatePlugin(
 *   id = "canonical_entities:node",
 *   forms = {
 *     "create-template" =
 *   "Drupal\template_entities\PluginForm\NodeTemplate\CreateTemplateForm",
 *   }
 * )
 */
class NodeTemplate extends TemplatePluginBase implements DependentPluginInterface, ConfigurableInterface {

  /**
   * {@inheritdoc}
   */
  public function duplicateEntity(EntityInterface $entity) {
    /** @var \Drupal\node\Entity\Node $duplicate_node */
    $duplicate_node = parent::duplicateEntity($entity);

    $request_time = Drupal::time()
      ->getRequestTime();

    $duplicate_node->setCreatedTime($request_time);

    // Make current user the owner.
    $duplicate_node->setOwnerId(Drupal::currentUser()->id());

    return $duplicate_node;
  }

  /**
   * @inheritDoc
   */
  public function calculateDependencies() {
    return [
      'module' => ['node'],
    ];
  }

  /**
   * @inheritDoc
   */
  public function getConfiguration() {
    return $this->configuration;
  }

  /**
   * @inheritDoc
   */
  public function setConfiguration(array $configuration) {
    $this->configuration = $configuration;
  }

  /**
   * @inheritDoc
   */
  public function defaultConfiguration() {
    return [];
  }

}
