<?php

namespace Drupal\template_entities\Plugin;

use Drupal\Component\Plugin\DerivativeInspectionInterface;
use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\Core\Database\Query\AlterableInterface;
use Drupal\Core\Entity\EntityInterface;
use Symfony\Component\Routing\RouteCollection;

/**
 * Defines an interface for Template plugin plugins.
 */
interface TemplatePluginInterface extends PluginInspectionInterface, DerivativeInspectionInterface {

  /**
   * Duplicate an entity.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity.
   *
   * @return \Drupal\Core\Entity\EntityInterface
   *   The new duplicate entity.
   */
  public function duplicateEntity(EntityInterface $entity);

  /**
   * Get the collection route name.
   *
   * @return string|FALSE
   */
  public function getCollectionLinkTemplate();

  /**
   * Allow plugins to alter tagged queries.
   *
   * @param \Drupal\Core\Database\Query\AlterableInterface $query
   *
   * @param array $template_types
   *
   * @return mixed
   */
  public function queryAlter(AlterableInterface $query, array $template_types);

  /**
   * Get the collection route.
   *
   * @param \Symfony\Component\Routing\RouteCollection $route_collection
   *
   * @return \Symfony\Component\Routing\RouteCollection|null A Route instance
   *   or null when not found
   */
  public function getCollectionRoute(RouteCollection $route_collection);

}
