<?php

namespace Drupal\template_entities;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\template_entities\Entity\TemplateType;

/**
 * Provides dynamic permissions for nodes of different types.
 */
class TemplatePermissions {

  use StringTranslationTrait;

  /**
   * Returns an array of template type permissions.
   *
   * @return array
   *   The template type permissions.
   * @see \Drupal\user\PermissionHandlerInterface::getPermissions()
   */
  public function templateTypePermissions() {
    $perms = [];
    // Generate node permissions for all node types.
    foreach (TemplateType::loadMultiple() as $type) {
      $perms += $this->buildPermissions($type);
    }

    return $perms;
  }

  /**
   * Returns a list of template permissions for a given template type.
   *
   * @param \Drupal\template_entities\Entity\TemplateType $type
   *   The template type.
   *
   * @return array
   *   An associative array of permission names and descriptions.
   */
  protected function buildPermissions(TemplateType $type) {
    $type_id = $type->id();
    $type_params = ['%type_name' => $type->label()];

    return [
      "manage $type_id template" => [
        'title' => $this->t('%type_name: Administer templates', $type_params),
      ],
      "new from $type_id template" => [
        'title' => $this->t('%type_name: Create new content from templates', $type_params),
      ],
    ];
  }

}
